@@ -54,6 +54,7 @@ int		network = 1;
 int		change = 0;
 int		case_sensitive = 1;
 int		report = 1;
+int		create_prefix = 0;
 char		transcript[ 2 * MAXPATHLEN ] = { 0 };
 char		prepath[ MAXPATHLEN ]  = { 0 };
 
@@ -63,7 +64,7 @@ extern int	showprogress;
 const EVP_MD    *md;
 SSL_CTX  	*ctx;
 
-extern char             *ca, *cert, *privatekey;
+extern char             *caFile, *caDir, *cert, *privatekey;
 
 struct node {
     char                *path;
@@ -251,7 +252,8 @@ main( int argc, char **argv )
     int			use_randfile = 0;
 	char        **capa = NULL; /* capabilities */
 
-    while (( c = getopt ( argc, argv, "%c:Fh:iInp:qru:Vvw:x:y:z:Z:" )) != EOF ) {
+    while (( c = getopt( argc, argv,
+	    "%c:CFh:iInp:P:qru:Vvw:x:y:z:Z:" )) != EOF ) {
 	switch( c ) {
 	case '%':
 	    showprogress = 1;
@@ -267,6 +269,10 @@ main( int argc, char **argv )
             cksum = 1;
             break;
 
+	case 'C':
+	    create_prefix = 1;
+	    break;
+
 	case 'F':
 	    force = 1;
 	    break;
@@ -297,6 +303,10 @@ main( int argc, char **argv )
 	    }
 	    break;
 
+        case 'P' :              /* ca dir */
+            caDir = optarg;
+            break;
+
 	case 'q':
 	    quiet = 1;
 	    break;
@@ -332,7 +342,7 @@ main( int argc, char **argv )
             break;
 
         case 'x' :              /* ca file */
-            ca = optarg;
+            caFile = optarg;
             break;
 
         case 'y' :              /* cert file */
@@ -393,10 +403,10 @@ main( int argc, char **argv )
     }
 
     if ( err ) {
-	fprintf( stderr, "usage: %s [ -FiInrV ] [ -%% | -q | -v ] ",
+	fprintf( stderr, "usage: %s [ -CFiInrV ] [ -%% | -q | -v ] ",
 	    argv[ 0 ] );
 	fprintf( stderr, "[ -c checksum ] [ -h host ] [ -p port ] " );
-	fprintf( stderr, "[ -u umask ] " );
+	fprintf( stderr, "[ -P ca-pem-directory ] [ -u umask ] " );
 	fprintf( stderr, "[ -w auth-level ] [ -x ca-pem-file ] " );
 	fprintf( stderr, "[ -y cert-pem-file ] [ -z key-pem-file ] " );
 	fprintf( stderr, "[ -Z compression-level ] " );
@@ -409,7 +419,7 @@ main( int argc, char **argv )
     }
 
     if ( authlevel != 0 ) {
-        if ( tls_client_setup( use_randfile, authlevel, ca, cert, 
+        if ( tls_client_setup( use_randfile, authlevel, caFile, caDir, cert, 
                 privatekey ) != 0 ) {
             /* error message printed in tls_setup */
             exit( 2 );
@@ -520,8 +530,7 @@ main( int argc, char **argv )
 	/* Check transcript order */
 	if ( prepath != 0 ) {
 	    if ( pathcasecmp( path, prepath, case_sensitive ) < 0 ) {
-		fprintf( stderr, "%s: line %d: bad sort order\n",
-			    transcript, linenum );
+		fprintf( stderr, "line %d: bad sort order\n", linenum );
 		goto error2;
 	    }
 	}
